derivationTable: Create a table based on first order derivative of the...

View source: R/predict.R

derivationTableR Documentation

Create a table based on first order derivative of the regression model for specific age

Description

In order to check model assumptions, a table of the first order derivative of the model coefficients is created.

Usage

derivationTable(A, model, minNorm = NULL, maxNorm = NULL, step = 0.1)

Arguments

A

the age

model

The regression model or a cnorm object

minNorm

The lower bound of the norm value range

maxNorm

The upper bound of the norm value range

step

Stepping parameter with lower values indicating higher precision

Value

data.frame with norm scores and the predicted scores based on the derived regression function

See Also

plotDerivative, derive

Other predict: getNormCurve(), normTable(), predict.cnormBetaBinomial(), predict.cnormBetaBinomial2(), predict.cnormShash(), predictNorm(), predictRaw(), rawTable()

Examples

## Not run: 
# Generate cnorm object from example data
cnorm.elfe <- cnorm(raw = elfe$raw, group = elfe$group)

# retrieve function for time point 6
d <- derivationTable(6, cnorm.elfe, step = 0.5)

## End(Not run)


cNORM documentation built on July 13, 2026, 5:08 p.m.