| diagnostics.shash | R Documentation |
This function computes detailed diagnostic statistics for a fitted shash model, including fit statistics, parameter estimates, and convergence information.
diagnostics.shash(object, age = NULL, score = NULL, weights = NULL)
object |
An object of class "cnormShash" |
age |
An optional numeric vector of age values for computing fit statistics |
score |
An optional numeric vector of raw scores for computing fit statistics |
weights |
An optional numeric vector of observation weights |
A list containing comprehensive diagnostic information
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.