This function computes the negative log-likelihood for a beta binomial regression model where both the mean and standard deviation are modeled as functions of predictors (mode 1, normal approximation on standardized scores).
log_likelihood(params, X, Z, y, weights = NULL)The negative log-likelihood of the model (large finite penalty if non-finite).
A numeric vector containing all model parameters. The first n_beta elements are coefficients for the mean model, and the remaining elements are coefficients for the log-standard deviation model.
A matrix of predictors for the mean model.
A matrix of predictors for the log-standard deviation model.
A numeric vector of response values.
A numeric vector of weights for each observation (NULL = equal weights).