plotRaw: Plot manifest and fitted raw scores

View source: R/plot.R

plotRawR Documentation

Plot manifest and fitted raw scores

Description

The function plots the raw data against the fitted scores from the regression model per group. This helps to inspect the precision of the modeling process. The scores should not deviate too far from regression line.

Usage

plotRaw(model, group = FALSE, type = 0)

Arguments

model

The regression model from the 'cnorm' function

group

Should the fit be displayed by group?

type

Type of display: 0 = plot manifest against fitted values, 1 = plot manifest against difference values

See Also

Other plot: compare(), plot.cnorm(), plot.cnormBetaBinomial(), plot.cnormBetaBinomial2(), plotDensity(), plotDerivative(), plotNorm(), plotNormCurves(), plotPercentileSeries(), plotPercentiles(), plotSubset()

Examples

## Not run: 
  # Compute model with example dataset and plot results
  result <- cnorm(raw = elfe$raw, group = elfe$group)
  plotRaw(result)

## End(Not run)

cNORM documentation built on July 13, 2026, 5:08 p.m.