rangeCheck: Check for horizontal and vertical extrapolation
Description
Regression models only work in a specific range and extrapolation
horizontally (outside the original range) or vertically (extreme norm
scores) might lead to inconsistent results. The function generates a
message, indicating extrapolation and the range of the original data.