standardizeRakingWeights: Function for standardizing raking weights

View source: R/raking.R

standardizeRakingWeightsR Documentation

Function for standardizing raking weights

Description

Raking weights get divided by the smallest weight. Thereby, all weights become larger or equal to 1 without changing the ratio of the weights to each other.

Usage

standardizeRakingWeights(weights)

Arguments

weights

Raking weights computed by computeWeights()

Value

the standardized weights


cNORM documentation built on July 13, 2026, 5:08 p.m.