Learn R Programming

cNORM (version 3.6.1)

diagnostics.betabinomial: Diagnostic Information for Beta-Binomial Model

Description

This function provides diagnostic information for a fitted beta-binomial model from the cnorm.betabinomial function. It returns various metrics related to model convergence, fit, and complexity. In case age and raw scores are provided, the function as well computes R2, RMSE and bias for the norm scores based on the manifest and predicted norm scores.

Usage

diagnostics.betabinomial(model, age = NULL, score = NULL, weights = NULL)

Value

A list containing diagnostic information, including convergence, number of evaluations, log-likelihood, AIC, BIC, parameter estimates with standard errors, z and p values, and - if age and score are provided - R2, RMSE and bias of the norm scores.

Arguments

model

An object of class "cnormBetaBinomial" or "cnormBetaBinomial2", typically the result of a call to cnorm.betabinomial().

age

An optional vector with age values.

score

An optional vector with raw values.

weights

An optional vector with weights.

Details

The AIC and BIC are calculated as: AIC = 2k - 2ln(L) BIC = ln(n)k - 2ln(L) where k is the number of parameters, L is the maximum likelihood, and n is the number of observations.

Examples

Run this code
if (FALSE) {
model <- cnorm.betabinomial(ppvt$age, ppvt$raw)
diag_info <- diagnostics.betabinomial(model)
print(diag_info)
summary(diag_info)

if(diag_info$converged) {
  cat("Model converged successfully.\n")
} else {
  cat("Warning: Model did not converge.\n")
}

cat("AIC:", diag_info$AIC, "\n")
cat("BIC:", diag_info$BIC, "\n")
}

Run the code above in your browser using DataLab