Learn R Programming

cNORM (version 3.6.1)

getNormScoreSE: Calculates the standard error (SE) or root mean square error (RMSE) of the norm scores. In case of large datasets, both results should be almost identical.

Description

Calculates the standard error (SE) or root mean square error (RMSE) of the norm scores. In case of large datasets, both results should be almost identical.

Usage

getNormScoreSE(model, type = 2)

Value

The standard error (SE) of the norm scores sensu Oosterhuis et al. (2016) or the RMSE

Arguments

model

a cnorm object

type

either '1' for the standard error sensu Oosterhuis et al. (2016) or '2' for the RMSE (default)

References

Oosterhuis, H. E. M., van der Ark, L. A., & Sijtsma, K. (2016). Sample Size Requirements for Traditional and Regression-Based Norms. Assessment, 23(2), 191-202. https://doi.org/10.1177/1073191115580638