| log_likelihood_shash | R Documentation |
This function computes the negative log-likelihood for a Sinh-Arcsinh regression model where the location, scale, and skewness parameters are modeled as functions of predictors.
log_likelihood_shash(
params,
X_mu,
X_sigma,
X_epsilon,
X_delta = NULL,
y,
weights = NULL,
fixed_delta = NULL
)
params |
A numeric vector containing all model parameters |
X_mu |
Design matrix for location parameter |
X_sigma |
Design matrix for scale parameter |
X_epsilon |
Design matrix for skewness parameter |
X_delta |
Design matrix for tails |
y |
Response vector |
weights |
Observation weights |
fixed_delta |
If not NULL, the delta parameter is fixed to this value |
The negative log-likelihood of the model
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.