This function computes the negative log-likelihood for a Sinh-Arcsinh regression model where the location, scale, skewness, and (optionally) tail weight parameters are modeled as functions of predictors.
log_likelihood_shash(
params,
X_mu,
X_sigma,
X_epsilon,
X_delta = NULL,
y,
weights = NULL,
fixed_delta = NULL
)The negative log-likelihood of the model
A numeric vector containing all model parameters
Design matrix for location parameter
Design matrix for scale parameter
Design matrix for skewness parameter
Design matrix for tail weight parameter (or NULL for fixed delta)
Response vector
Observation weights
If not NULL, the delta parameter is fixed to this value