This function generates a norm table for specific ages based on the beta binomial regression model. In case a confidence coefficient (CI, default .9) and the reliability is specified, confidence intervals are computed for the true score estimates, including a correction for regression to the mean (Eid & Schmidt, 2012, p. 272).
normTable.betabinomial(
model,
ages,
n = NULL,
m = NULL,
range = 3,
CI = 0.9,
reliability = NULL
)A list of data frames with columns: x, Px, Pcum, Percentile, z, norm score and possibly confidence intervals.
The model, fitted with cnorm.betabinomial.
A numeric vector of age points at which to compute the tables.
The number of items resp. the maximum score.
An optional stop criterion in table generation. Positive integer lower than n. Please note: The probabilities are always computed on the full support 0 to n; m only truncates the output table.
The range of the norm scores in standard deviations. Default is 3. Thus, scores in the range of +/- 3 standard deviations are considered.
Confidence coefficient, ranging from 0 to 1, default .9.
Reliability coefficient, ranging between 0 to 1.