| plot.cnormBetaBinomial2 | R Documentation |
This function creates a visualization of a fitted cnormBetaBinomial2
model, including the original data points, manifest percentiles and
specified percentile lines. See plot.cnormBetaBinomial.
## S3 method for class 'cnormBetaBinomial2'
plot(x, ...)
x |
A fitted model object of class "cnormBetaBinomial" or "cnormBetaBinomial2". |
... |
Additional arguments passed to the plot method.
|
A ggplot object.
Other plot:
compare(),
plot.cnorm(),
plot.cnormBetaBinomial(),
plotDensity(),
plotDerivative(),
plotNorm(),
plotNormCurves(),
plotPercentileSeries(),
plotPercentiles(),
plotRaw(),
plotSubset()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.