Learn R Programming

cNORM (version 3.6.1)

plot.cnormBetaBinomial2: Plot cnormBetaBinomial2 Model with Data and Percentile Lines

Description

This function creates a visualization of a fitted cnormBetaBinomial2 model, including the original data points, manifest percentiles and specified percentile lines. See plot.cnormBetaBinomial.

Usage

# S3 method for cnormBetaBinomial2
plot(x, ...)

Value

A ggplot object.

Arguments

x

A fitted model object of class "cnormBetaBinomial" or "cnormBetaBinomial2".

...

Additional arguments passed to the plot method.

  • age A vector of the age data.

  • score A vector of the score data.

  • weights An optional numeric vector of weights for each observation.

  • percentiles An optional vector with the percentiles to plot.

  • points Logical indicating whether to plot the data points. Default is TRUE.

  • discrete Logical indicating whether to plot the discrete raw scores. Default is FALSE.

See Also

Other plot: compare(), plot.cnorm(), plot.cnormBetaBinomial(), plotDensity(), plotDerivative(), plotNorm(), plotNormCurves(), plotPercentileSeries(), plotPercentiles(), plotRaw(), plotSubset()