Learn R Programming

cNORM (version 3.6.1)

predict.cnormBetaBinomial2: Predict Norm Scores from Raw Scores

Description

This function calculates norm scores based on raw scores, age, and a fitted cnormBetaBinomial2 model. See predict.cnormBetaBinomial for details.

Usage

# S3 method for cnormBetaBinomial2
predict(object, ...)

Value

A numeric vector of norm scores.

Arguments

object

A fitted model object of class 'cnormBetaBinomial' or 'cnormBetaBinomial2'.

...

Additional arguments passed to the prediction method:

  • age A numeric vector of ages, same length as score.

  • score A numeric vector of raw scores.

  • range The range of the norm scores in standard deviations. Default is 3.

See Also

Other predict: derivationTable(), getNormCurve(), normTable(), predict.cnormBetaBinomial(), predict.cnormShash(), predictNorm(), predictRaw(), rawTable()