| predictCoefficients2 | R Documentation |
This function generates predictions from a fitted beta-binomial regression model (mode 2) for new age points.
predictCoefficients2(model, ages, n = NULL)
model |
An object of class "cnormBetaBinomial2". |
ages |
A numeric vector of age points at which to make predictions. |
n |
The maximum score to be achieved. |
The function applies the same standardization used in model fitting and
the same clamping of the linear predictors (\pm 20 on the log scale)
as the likelihood function, ensuring consistent behavior also under
(mild) extrapolation.
A data frame with columns:
age |
The input age points |
a |
Predicted alpha values |
b |
Predicted beta values |
mu |
Predicted mean values |
sigma |
Predicted standard deviation values |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.