| printSubset | R Documentation |
Displays R^2 and other metrics for models with varying predictors, aiding in choosing the best-fitting model after model fitting. The F-test compares each model to the preceding (smaller) one, with degrees of freedom based on the actual difference in the number of parameters.
printSubset(x, ...)
x |
Model output from 'bestModel' or a cnorm object. |
... |
Additional parameters. |
Table with model information criteria.
Other model:
bestModel(),
checkConsistency(),
cnorm.cv(),
derive(),
modelSummary(),
print.cnorm(),
rangeCheck(),
regressionFunction(),
summary.cnorm(),
weightedAverageModel()
## Not run:
result <- cnorm(raw = elfe$raw, group = elfe$group)
printSubset(result)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.