Learn R Programming

cNORM (version 3.6.1)

printSubset: Print Model Selection Information

Description

Displays R^2 and other metrics for models with varying predictors, aiding in choosing the best-fitting model after model fitting. The F-test compares each model to the preceding (smaller) one, with degrees of freedom based on the actual difference in the number of parameters.

Usage

printSubset(x, ...)

Value

Table with model information criteria.

Arguments

x

Model output from 'bestModel' or a cnorm object.

...

Additional parameters.

See Also

Other model: bestModel(), checkConsistency(), cnorm.cv(), derive(), modelSummary(), print.cnorm(), rangeCheck(), regressionFunction(), summary.cnorm(), weightedAverageModel()

Examples

Run this code
if (FALSE) {
  result <- cnorm(raw = elfe$raw, group = elfe$group)
  printSubset(result)
}

Run the code above in your browser using DataLab