Learn R Programming

cNORM (version 3.6.1)

standardizeRakingWeights: Function for standardizing raking weights

Description

Raking weights get divided by the smallest weight. Thereby, all weights become larger or equal to 1 without changing the ratio of the weights to each other.

Usage

standardizeRakingWeights(weights)

Value

the standardized weights

Arguments

weights

Raking weights computed by computeWeights()