| subsample_lm | R Documentation |
Deprecated. Averaging OLS coefficients over subsamples or folds cannot
improve upon the full-sample (weighted) least squares fit, which is already
the minimum-variance unbiased estimator for a fixed set of terms
(Gauss-Markov); it merely adds Monte-Carlo noise and small-sample bias. The
relevant source of variance is model *selection*, which is addressed by
consistency screening and by BIC-weighted model averaging
(bestModel(..., averaging = TRUE) or weightedAverageModel).
This function now simply returns the full-sample least squares fit.
subsample_lm(text, data, weights, k = 10)
text |
A character string or formula specifying the model to be fitted |
data |
A data frame containing the variables in the model |
weights |
Optional numeric vector of weights |
k |
Ignored (kept for backwards compatibility) |
An object of class 'lm' fitted on the complete sample.
weightedAverageModel
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.