| weighted.rank | R Documentation |
Conducts weighted ranking on the basis of sums of weights per unique raw score.
Please provide a vector with raw values and an additional vector with the weight
of each observation. In case the weight vector is NULL, a normal ranking is done.
The vectors may not include NAs and the weights should be positive non-zero
values. With equal weights, the result reproduces the mid-ranks of base R's
rank() (ties.method = "average").
weighted.rank(x, weights = NULL)
x |
A numerical vector |
weights |
A numerical vector with weights; should have the same length as x |
the weighted absolute ranks
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.